@@ -8,11 +8,15 @@ from pathlib import Path
 import mailbox
 import re
 import os
+import sys
 import urllib
 import yaml
-
+from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 class Thunderbird(object):
+    '''
+    Thunderbird Mailbox access
+    '''
     profiles={}
     
     def __init__(self,user,db=None,profile=None):
@@ -31,11 +35,14 @@ class Thunderbird(object):
         else:
             self.db=db
             self.profile=profile
-        self.sqlDB=SQLDB(self.db)
+        self.sqlDB=SQLDB(self.db,check_same_thread=False,timeout=5)
         pass
      
     @staticmethod
     def getProfileMap():
+        '''
+        get the profile map from a thunderbird.yaml file
+        '''
         home = str(Path.home())
         profilesPath=home+"/.thunderbird.yaml"
         with open(profilesPath, 'r') as stream:
@@ -64,10 +71,12 @@ class Mail(object):
             debug(bool): True if debugging should be activated
             keySearch(bool): True if a slow keySearch should be tried when lookup fails
         '''
+        self.debug=debug
         self.tb=Thunderbird.get(user)
+        if self.debug:
+            print(f"Searching for mail with id {mailid} for user {user}")
         mailid=re.sub(r"\<(.*)\>",r"\1",mailid)
         self.mailid=mailid
-        self.debug=debug
         self.keySearch=keySearch
         self.msg=None
         query="""select m.*,f.* 
@@ -135,6 +144,67 @@ where m.headerMessageID==(?)"""
         m.set_payload(content)
         return m       
                 
+    
+__version__ = "0.0.7"
+__date__ = '2021-09-23'
+__updated__ = '2021-09-23'    
+
+DEBUG = 1
+
+    
+def main(argv=None): # IGNORE:C0111
+    '''main program.'''
+
+    if argv is None:
+        argv=sys.argv[1:]
         
+    program_name = os.path.basename(__file__)
+    program_version = "v%s" % __version__
+    program_build_date = str(__updated__)
+    program_version_message = '%%(prog)s %s (%s)' % (program_version, program_build_date)
+    program_shortdesc = "script to retrieve thunderbird mail via user and mailid"
+    user_name="Wolfgang Fahl"
+    program_license = '''%s
+
+  Created by %s on %s.
+  Copyright 2020-2021 Wolfgang Fahl. All rights reserved.
+
+  Licensed under the Apache License 2.0
+  http://www.apache.org/licenses/LICENSE-2.0
+
+  Distributed on an "AS IS" basis without warranties
+  or conditions of any kind, either express or implied.
+
+USAGE
+''' % (program_shortdesc,user_name, str(__date__))
+
+    try:
+        # Setup argument parser
+        parser = ArgumentParser(description=program_license, formatter_class=RawDescriptionHelpFormatter)
+        parser.add_argument("-d", "--debug", dest="debug", action="count", help="set debug level [default: %(default)s]")
+        parser.add_argument('-V', '--version', action='version', version=program_version_message)
+        parser.add_argument('-u','--user',type=str,help="id of the user")       
+        parser.add_argument('-i','--id',type=str,help="id of the mail to retrieve")
+  
+        # Process arguments
+        args = parser.parse_args(argv)
+        mail=Mail(user=args.user,mailid=args.id,debug=args.debug)
+        print (mail.msg)
+
+    except KeyboardInterrupt:
+        ### handle keyboard interrupt ###
+        return 1
+    except Exception as e:
+        if DEBUG:
+            raise(e)
+        indent = len(program_name) * " "
+        sys.stderr.write(program_name + ": " + repr(e) + "\n")
+        sys.stderr.write(indent + "  for help use --help")
+        return 2     
+    
+if __name__ == "__main__":
+    if DEBUG:
+        sys.argv.append("-d")
+    sys.exit(main())
         
         
\ No newline at end of file
